# tacoreader

[![PyPI](https://img.shields.io/pypi/v/tacoreader.svg)](https://pypi.python.org/pypi/tacoreader)
[![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)
[![BlueSky](https://img.shields.io/badge/bluesky-tacofoundation-1185fe?labelColor=000000&logo=bluesky)](https://bsky.app/profile/tacofoundation.bsky.social)
[![Checked with mypy](https://www.mypy-lang.org/static/mypy_badge.svg)](https://mypy-lang.org/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Linting: Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)


A prototype implementation of the TACO Reader API specification.

Status: Work in progress. Currently migrating to v2.0 specification.

Legacy Support: Version 1.0 remains available in tacoreader.v1 subpackage
